@@ -147,8 +147,9 @@ This module is used internally to load C<.dataprinter> files.
 
 =head1 THE RC FILE
 
-    # line comments are ok, DO NOT USE inline comments at the end of a line!
-    ; this is also a line comment
+    # line comments are ok with "#" or ";"
+    ; this is also a full line comment.
+    ; Comments at the end of a line (inline) are not allowed
     multiline  = 0
     hash_max   = 5
     array_max  = 5
@@ -168,6 +169,29 @@ This module is used internally to load C<.dataprinter> files.
     [Other::Class]
     theme = Monokai
 
+=head1 PUBLIC INTERFACE
+
+This module is not meant for public use. However, because Data::Printer
+changed the format of the configuration file, we provide the following
+public function for people to use:
+
+=head2 convert( $filename )
+
+    perl -MDDP -E 'say Data::Printer::Config::convert( q(/path/to/my/.dataprinter) )'
+
+Loads a deprecated (pre-1.0) configuration file and returns a string
+with a converted version, which you can use for newer (post-1.0) versions.
+
+Other public functions, not really meant for general consumption, are:
+
+=over 4
+
+=item * C<load_rc_file( $filename )> - loads a configuration file and returns
+the associated data structure. If no filename is provided, looks
+for C<.dataprinter>.
+
+=back
+
 =head1 SEE ALSO
 
 L<Data::Printer>
